import 'package:flutter/material.dart';
import 'package:syncrow_web/pages/space_management_v2/main_module/widgets/plus_button_widget.dart';

class SpaceCardWidget extends StatelessWidget {
  final int index;
  final Size screenSize;
  final Offset position;
  final bool isHovered;
  final void Function(int index, bool isHovered) onHoverChanged;
  final void Function(int index, Offset newPosition) onButtonTap;
  final Widget Function(int index) buildSpaceContainer;
  final ValueChanged<Offset> onPositionChanged;

  const SpaceCardWidget({
    super.key,
    required this.index,
    required this.onPositionChanged,
    required this.screenSize,
    required this.position,
    required this.isHovered,
    required this.onHoverChanged,
    required this.onButtonTap,
    required this.buildSpaceContainer,
  });

  @override
  Widget build(BuildContext context) {
    return MouseRegion(
      onEnter: (_) => onHoverChanged(index, true),
      onExit: (_) => onHoverChanged(index, false),
      child: SizedBox(
        width: 150,
        height: 90,
        child: Stack(
          clipBehavior: Clip.none,
          alignment: Alignment.center,
          children: [
            buildSpaceContainer(index),

            if (isHovered)
              Positioned(
                bottom: 0,
                child: PlusButtonWidget(
                  index: index,
                  direction: 'down',
                  offset: Offset.zero,
                  onButtonTap: onButtonTap,
                ),
              ),
            if (isHovered)
              Positioned(
                right: -15,
                child: PlusButtonWidget(
                  index: index,
                  direction: 'right',
                  offset: Offset.zero,
                  onButtonTap: onButtonTap,
                ),
              ),
          ],
        ),
      ),
    );
  }
}
